"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("dotenv/config");
const yargs_1 = __importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const loader_1 = __importDefault(require("./loader"));
const log_manager_1 = __importDefault(require("../utils/log-manager"));
const sourceFileDir = process.env.CSV_INPUT_DIR;
const targetDir = process.env.CSV_OUTPUT_DIR;
const csvTransformationDir = process.env.CSV_TRANSFORMATION_DIR;
const batchSize = Number(process.env.BATCH_SIZE) || 500;
// eslint-disable-next-line no-unused-expressions
(0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
    .usage("$0 [csv2jsonl]")
    .option("logLevel", {
    alias: "log-level",
    demandOption: false,
    default: "debug",
    requiresArg: true,
    choices: ["off", "error", "warn", "info", "debug"],
    describe: "The logging level to specify for the execution.",
    type: "string",
})
    .option("saveToFile", {
    alias: "saveToFile",
    demandOption: false,
    requiresArg: false,
    describe: "Save transformed file to file.",
    type: "string",
})
    .option("type", {
    alias: "type",
    demandOption: false,
    requiresArg: true,
    choices: ["product", "variation", "price", "image"],
    default: "product",
    describe: "Object type.",
    type: "string",
})
    .command("csv2jsonl <inputFile> <transformationFile> [pricebookId]", "Transform csv to canonical format", (yargs) => {
    yargs.positional("transformationFile", {
        describe: "Filename of jsonata transformation logic.",
        type: "string",
    });
    yargs.positional("inputFile", {
        describe: "The CSV file that contains objects to transform to canonical model.",
        type: "string",
    });
    yargs.positional("pricebookId", {
        describe: "[Optional] Id of the pricebook. Used only in price transformation.",
        type: "string",
    });
}, (argv) => {
    log_manager_1.default.configureLogging(console, argv.logLevel);
    const saveToFile = argv.saveToFile !== undefined;
    loader_1.default.readCsvFileAndProcess(sourceFileDir + argv.inputFile, csvTransformationDir + argv.transformationFile, targetDir + argv.type + "-" + argv.inputFile, argv.type, {
        batchSize,
        saveToFile,
        pricebookId: argv.pricebookId,
    });
})
    .demandCommand()
    .recommendCommands()
    .help().argv;
