"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.content = exports.transform = void 0;
// eslint-disable-next-line @typescript-eslint/no-var-requires
const jsonata = require("jsonata");
const log_manager_1 = __importDefault(require("../utils/log-manager"));
const promises_1 = require("fs/promises");
const fs = __importStar(require("fs"));
const logger = log_manager_1.default.getLogger("csv2jsonl");
// eslint-disable-next-line max-params
function transform(items, transformationFile, targetFile, objectType, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { saveToFile, pricebookId } = options;
        logger.info(`Processing ${items.length} items to extract ${objectType}.`);
        const result = yield transformSequential(items, transformationFile, {
            pricebookId,
            saveToFile,
        });
        if (saveToFile === true) {
            saveResultToFile(result, targetFile.replace(".csv", ".jsonl"));
            logger.info("Saved to file: " + targetFile.replace(".csv", ".jsonl"));
        }
        else {
            logger.info(`Transformation result:\n${JSON.stringify(result, null, 3)}`);
        }
        return result;
    });
}
exports.transform = transform;
function saveResultToFile(result, targetFile) {
    const writeStream = fs.createWriteStream(targetFile, {
        encoding: "utf-8",
    });
    for (let i = 0; i < result.length; i++) {
        writeStream.write(JSON.stringify(result[i]) + "\n");
    }
    writeStream.end();
}
function transformSequential(items, transformationFile, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const transformer = yield content(transformationFile);
        const expression = jsonata(transformer);
        const { saveToFile } = options;
        let result = { result: [], row: "" };
        for (const p of items) {
            result.row = p;
            // eslint-disable-next-line no-await-in-loop
            result = yield expression.evaluate(result, options);
            if (saveToFile === false) {
                logger.debug(`Item before transformation:\n ${JSON.stringify(p, null, 3)}\n
      Item transformation result:\n ${JSON.stringify(result, null, 3)}\n`);
            }
        }
        logger.info(`Processed ${items.length} items. Extracted ${result.result.length}.`);
        return result.result;
    });
}
function content(path) {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, promises_1.readFile)(path, "utf8");
    });
}
exports.content = content;
