"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// eslint-disable-next-line @typescript-eslint/no-var-requires
const eventStream = require("event-stream");
const fs_1 = require("fs");
const events_1 = require("events");
const parse_1 = require("@fast-csv/parse");
const csv2jsonl_1 = require("./csv2jsonl");
const log_manager_1 = __importDefault(require("../utils/log-manager"));
const logger = log_manager_1.default.getLogger("loader");
let buffer = [];
// eslint-disable-next-line max-params
function readCsvFileAndProcess(sourceFilePath, transformationFilePath, targetFile, objectType, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { batchSize, saveToFile, pricebookId } = options;
        buffer = [];
        const pause = eventStream.pause();
        const pipeline = (0, fs_1.createReadStream)(sourceFilePath)
            .pipe((0, parse_1.parse)({ headers: true, ignoreEmpty: true }))
            .pipe(pause)
            .on("data", (record) => __awaiter(this, void 0, void 0, function* () {
            if (buffer.push(record) === batchSize) {
                pause.pause();
                yield (0, csv2jsonl_1.transform)(buffer, transformationFilePath, targetFile, objectType, { saveToFile, pricebookId });
                buffer = [];
                pause.resume();
            }
        }))
            .on("error", (error) => {
            logger.error(`Error processing file:`, error);
        });
        if (pipeline) {
            yield (0, events_1.once)(pipeline, "end");
            if (buffer.length > 0) {
                yield (0, csv2jsonl_1.transform)(buffer, transformationFilePath, targetFile, objectType, {
                    saveToFile,
                    pricebookId,
                });
            }
        }
    });
}
module.exports = {
    readCsvFileAndProcess,
};
exports.default = { readCsvFileAndProcess };
