"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("dotenv/config");
const yargs_1 = __importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const log_manager_1 = __importDefault(require("../utils/log-manager"));
const loader_1 = require("./loader");
const batchSize = Number(process.env.BATCH_SIZE) || 500;
const imageImportConcurrency = Number(process.env.IMAGE_IMPORT_CONCURRENCY) || 5;
// eslint-disable-next-line no-unused-expressions
(0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
    .usage("$0 [importImages]")
    .option("logLevel", {
    alias: "log-level",
    demandOption: false,
    default: "info",
    requiresArg: true,
    choices: ["off", "error", "warn", "info", "debug"],
    describe: "The logging level to specify for the execution.",
    type: "string",
})
    .option("deleteExisting", {
    alias: "deleteExisting",
    demandOption: false,
    requiresArg: false,
    describe: "Delete existin images associated with the file.",
    type: "string",
})
    .option("imageConfigFile", {
    alias: "imageConfigFile",
    demandOption: false,
    requiresArg: true,
    describe: "The json file containing images to import. This can also be supplied via a IMAGE_CONFIG_PATH environment variable.",
    type: "string",
})
    .option("imageDirectory", {
    alias: "imageDirectory",
    demandOption: false,
    requiresArg: true,
    describe: "Directory with images to load. This can also be supplied via a IMAGE_DIRECTORY environment variable.",
    type: "string",
})
    .command("importImages", "Import images", 
// eslint-disable-next-line @typescript-eslint/no-empty-function
(yargs) => { }, (argv) => __awaiter(void 0, void 0, void 0, function* () {
    log_manager_1.default.configureLogging(console, argv.logLevel);
    const deleteExisting = argv.deleteExisting !== undefined;
    const sourceFilePath = argv.imageConfigFile !== undefined ? argv.imageConfigFile : String(process.env.IMAGE_CONFIG_PATH);
    const imageDirectory = argv.imageDirectory !== undefined ? argv.imageDirectory : String(process.env.IMAGE_DIRECTORY);
    yield (0, loader_1.readFileAndLoad)(sourceFilePath, imageDirectory, {
        batchSize,
        deleteExisting,
        imageImportConcurrency,
    });
}))
    .demandCommand()
    .recommendCommands()
    .help().argv;
