"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readFileAndLoad = void 0;
/* eslint-disable new-cap */
const log_manager_1 = __importDefault(require("../utils/log-manager"));
const logger = log_manager_1.default.getLogger("image-loader");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const eventStream = require("event-stream");
const fs_1 = require("fs");
const events_1 = require("events");
const image_importer_1 = __importDefault(require("./image-importer"));
const gateway_1 = require("../utils/gateway");
let buffer = [];
function readFileAndLoad(sourceFilePath, imageDirectory, options) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("readFileAndLoad");
        const { batchSize, deleteExisting, imageImportConcurrency } = options;
        const processedSku = [];
        buffer = [];
        const pause = eventStream.pause();
        const pipeline = (0, fs_1.createReadStream)(sourceFilePath)
            .pipe(eventStream.split())
            .pipe(eventStream.parse({ error: true }))
            .pipe(pause)
            .on("data", (record) => __awaiter(this, void 0, void 0, function* () {
            if (buffer.push(record) === batchSize) {
                pause.pause();
                yield image_importer_1.default.importImages(gateway_1.gateway, buffer, imageDirectory, processedSku, {
                    deleteExisting,
                    imageImportConcurrency,
                });
                logger.info(`Processed ${buffer.length} images.`);
                buffer = [];
                pause.resume();
            }
        }))
            .on("error", (error) => {
            logger.error(`Error processing file:`, error);
        });
        if (pipeline) {
            yield (0, events_1.once)(pipeline, "end");
            if (buffer.length > 0) {
                yield image_importer_1.default.importImages(gateway_1.gateway, buffer, imageDirectory, processedSku, {
                    deleteExisting,
                    imageImportConcurrency,
                });
            }
            logger.info(`Processed ${buffer.length} images.`);
        }
    });
}
exports.readFileAndLoad = readFileAndLoad;
