import "dotenv/config";
import yargs from "yargs";
import { hideBin } from "yargs/helpers";
import loader from "./loader";
import logManager from "../utils/log-manager";
const sourceFileDir = process.env.CSV_INPUT_DIR;
const targetDir = process.env.CSV_OUTPUT_DIR;
const csvTransformationDir = process.env.CSV_TRANSFORMATION_DIR;
const batchSize = Number(process.env.BATCH_SIZE) || 500;
// eslint-disable-next-line no-unused-expressions
yargs(hideBin(process.argv))
    .usage("$0 [csv2jsonl]")
    .option("logLevel", {
    alias: "log-level",
    demandOption: false,
    default: "debug",
    requiresArg: true,
    choices: ["off", "error", "warn", "info", "debug"],
    describe: "The logging level to specify for the execution.",
    type: "string",
})
    .option("saveToFile", {
    alias: "saveToFile",
    demandOption: false,
    requiresArg: false,
    describe: "Save transformed file to file.",
    type: "string",
})
    .option("type", {
    alias: "type",
    demandOption: false,
    requiresArg: true,
    choices: ["product", "variation", "price", "image"],
    default: "product",
    describe: "Object type.",
    type: "string",
})
    .command("csv2jsonl <inputFile> <transformationFile> [pricebookId]", "Transform csv to canonical format", (yargs) => {
    yargs.positional("transformationFile", {
        describe: "Filename of jsonata transformation logic.",
        type: "string",
    });
    yargs.positional("inputFile", {
        describe: "The CSV file that contains objects to transform to canonical model.",
        type: "string",
    });
    yargs.positional("pricebookId", {
        describe: "[Optional] Id of the pricebook. Used only in price transformation.",
        type: "string",
    });
}, (argv) => {
    logManager.configureLogging(console, argv.logLevel);
    const saveToFile = argv.saveToFile !== undefined;
    loader.readCsvFileAndProcess(sourceFileDir + argv.inputFile, csvTransformationDir + argv.transformationFile, targetDir + argv.type + "-" + argv.inputFile, argv.type, {
        batchSize,
        saveToFile,
        pricebookId: argv.pricebookId,
    });
})
    .demandCommand()
    .recommendCommands()
    .help().argv;
