var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// eslint-disable-next-line @typescript-eslint/no-var-requires
const jsonata = require("jsonata");
import logManager from "../utils/log-manager";
import { readFile } from "fs/promises";
import * as fs from "fs";
const logger = logManager.getLogger("csv2jsonl");
// eslint-disable-next-line max-params
export function transform(items, transformationFile, targetFile, objectType, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { saveToFile, pricebookId } = options;
        logger.info(`Processing ${items.length} items to extract ${objectType}.`);
        const result = yield transformSequential(items, transformationFile, {
            pricebookId,
            saveToFile,
        });
        if (saveToFile === true) {
            saveResultToFile(result, targetFile.replace(".csv", ".jsonl"));
            logger.info("Saved to file: " + targetFile.replace(".csv", ".jsonl"));
        }
        else {
            logger.info(`Transformation result:\n${JSON.stringify(result, null, 3)}`);
        }
        return result;
    });
}
function saveResultToFile(result, targetFile) {
    const writeStream = fs.createWriteStream(targetFile, {
        encoding: "utf-8",
    });
    for (let i = 0; i < result.length; i++) {
        writeStream.write(JSON.stringify(result[i]) + "\n");
    }
    writeStream.end();
}
function transformSequential(items, transformationFile, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const transformer = yield content(transformationFile);
        const expression = jsonata(transformer);
        const { saveToFile } = options;
        let result = { result: [], row: "" };
        for (const p of items) {
            result.row = p;
            // eslint-disable-next-line no-await-in-loop
            result = yield expression.evaluate(result, options);
            if (saveToFile === false) {
                logger.debug(`Item before transformation:\n ${JSON.stringify(p, null, 3)}\n
      Item transformation result:\n ${JSON.stringify(result, null, 3)}\n`);
            }
        }
        logger.info(`Processed ${items.length} items. Extracted ${result.result.length}.`);
        return result.result;
    });
}
export function content(path) {
    return __awaiter(this, void 0, void 0, function* () {
        return readFile(path, "utf8");
    });
}
