var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
// eslint-disable-next-line @typescript-eslint/no-var-requires
const eventStream = require("event-stream");
import { createReadStream } from "fs";
import { once } from "events";
import { parse } from "@fast-csv/parse";
import { transform } from "./csv2jsonl";
import logManager from "../utils/log-manager";
const logger = logManager.getLogger("loader");
let buffer = [];
// eslint-disable-next-line max-params
function readCsvFileAndProcess(sourceFilePath, transformationFilePath, targetFile, objectType, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { batchSize, saveToFile, pricebookId } = options;
        buffer = [];
        const pause = eventStream.pause();
        const pipeline = createReadStream(sourceFilePath)
            .pipe(parse({ headers: true, ignoreEmpty: true }))
            .pipe(pause)
            .on("data", (record) => __awaiter(this, void 0, void 0, function* () {
            if (buffer.push(record) === batchSize) {
                pause.pause();
                yield transform(buffer, transformationFilePath, targetFile, objectType, { saveToFile, pricebookId });
                buffer = [];
                pause.resume();
            }
        }))
            .on("error", (error) => {
            logger.error(`Error processing file:`, error);
        });
        if (pipeline) {
            yield once(pipeline, "end");
            if (buffer.length > 0) {
                yield transform(buffer, transformationFilePath, targetFile, objectType, {
                    saveToFile,
                    pricebookId,
                });
            }
        }
    });
}
module.exports = {
    readCsvFileAndProcess,
};
export default { readCsvFileAndProcess };
