// TODO move entire module to data-import-automation
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { BUILD_DIR, DATA_DIR, IMAGE_ASSOC_FILENAME, IMAGE_ASSOC_DIR, CONFIG_IMAGEASSOC_DEST } from "../constants";
import path from "path";
import fs from "fs";
export class ImageAssocation {
    getGruntConfig() {
        return {
            transform_image_assoc: {
                all: {
                    image_assoc: path.join(DATA_DIR, IMAGE_ASSOC_DIR),
                    images: path.join(DATA_DIR, "images"),
                    dest_path: path.join(BUILD_DIR),
                    dest_name: IMAGE_ASSOC_FILENAME,
                },
            },
            json2jsonl: {
                convert_json_image_assoc_file_to_jsonl: {
                    src: [path.join(BUILD_DIR, IMAGE_ASSOC_FILENAME)],
                    dest: path.join(BUILD_DIR),
                    ext: ".jsonl",
                },
            },
            concat: {
                image_assoc_json_files: {
                    // todo change filename
                    src: [path.join(BUILD_DIR, IMAGE_ASSOC_DIR, "**", IMAGE_ASSOC_FILENAME)],
                    dest: CONFIG_IMAGEASSOC_DEST,
                    options: {
                        // Start of array added to the top of the file
                        banner: "[",
                        // End of array added at the end of the file
                        footer: "]",
                        // Array separator
                        separator: ",",
                        process: function (src, _filepath) {
                            // Convert array to bunch of comma separated items without enclosing "[]"
                            const mappings = JSON.parse(src);
                            let output = "";
                            output += mappings.map((mapping) => JSON.stringify(mapping, null, 2));
                            return output;
                        },
                    },
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask("transform_image_assoc", function () {
            transformImageAssociations(grunt, this);
        });
    }
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const transformImageAssociations = function (grunt, grunt_this) {
    return __awaiter(this, void 0, void 0, function* () {
        const imageAssocBaseFolder = grunt_this.data.image_assoc;
        console.log("assoc base=" + imageAssocBaseFolder);
        grunt.file.recurse(imageAssocBaseFolder, (abspath, _rootdir, _subdir, _filename) => __awaiter(this, void 0, void 0, function* () {
            const association = grunt.file.readJSON(abspath);
            console.log("Reading image associations from " + abspath);
            const targetFolder = path.join(path.resolve(grunt_this.data.dest_path), IMAGE_ASSOC_DIR, association.sku_code);
            const targetFile = path.join(targetFolder, grunt_this.data.dest_name);
            console.log("targetFolder=" + targetFolder);
            if (!fs.existsSync(targetFolder)) {
                fs.mkdirSync(targetFolder, { recursive: true });
            }
            const lines = processImageAssocation(association);
            grunt.file.write(targetFile, JSON.stringify(lines, null, 2));
        }));
    });
};
/*
example association:
{
  sku_code: 'sku_black_romper_dress',
  main_image_file_name: 'womens/clothing/black_romper_dress/pexels-jeff-denlea-8965403.jpg',
  other_image_file_names: [
    'womens/clothing/black_romper_dress/pexels-jeff-denlea-8179876.jpg',
    'womens/clothing/black_romper_dress/pexels-jeff-denlea-8965407.jpg',
  ]
}
example destination: build/development/image-assoc/sku_black_romper_dress/image-assoc.jsonl

example output:
[
  {
    sku: 'sku_black_romper_dress',
    main_image: true,
    file_name: 'womens/clothing/black_romper_dress/pexels-jeff-denlea-8965403.jpg'
  },
  {
    sku: 'sku_black_romper_dress',
    main_image: false,
    file_name: 'womens/clothing/black_romper_dress/pexels-jeff-denlea-8179876.jpg'
  },
  {
    sku: 'sku_black_romper_dress',
    main_image: false,
    file_name: 'womens/clothing/black_romper_dress/pexels-jeff-denlea-8965407.jpg'
  },
]
*/
// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const processImageAssocation = (association) => {
    const lines = [];
    const sku = association.sku_code;
    if (association.main_image_file_name) {
        const line = {
            sku: sku,
            main_image: true,
            file_name: path.join(DATA_DIR, "images", association.main_image_file_name),
        };
        lines.push(line);
    }
    if (association.other_image_file_names) {
        const images = association.other_image_file_names.map((fileName) => {
            return { sku: sku, main_image: false, file_name: path.join(DATA_DIR, "images", fileName) };
        });
        lines.push(...images);
    }
    return lines;
};
