export class ValidateEnv {
    getGruntConfig() {
        return {
            validate_env: {
                all: {
                    msg: 'Successful validation of env!',
                },
            },
        };
    }
    registerTasks(grunt) {
        grunt.registerMultiTask('validate_env', function () {
            validateEnv(grunt, this);
        });
    }
}
export const validateEnv = function (grunt, grunt_this) {
    if (!process.env.EPCC_ENV) {
        grunt.fail.fatal(`EPCC_ENV MUST exist in your environment file and needs to be sourced before running grunt.\n(1) Add EPCC_ENV to your env file (eg ".env.mydev")\n(2) run shell command: "export $(grep -v '^#' .env.mydev | xargs)" `);
    }
    const optionalVars = [
        'IH_ORCHESTRATOR_URL',
        'IH_ORCHESTRATOR_API_KEY',
        'IH_NODE_LOADER_API_KEY',
        'IH_NODE_LOADER_URL',
        'IH_PRICE_LOADER_API_KEY',
        'IH_PRICE_LOADER_URL',
        'IH_PRODUCT_LOADER_URL',
        'IH_PRODUCT_LOADER_API_KEY',
        'IH_INVENTORY_LOADER_URL',
        'IH_INVENTORY_LOADER_API_KEY',
        'IH_ASSOC_LOADER_URL',
        'IH_ASSOC_LOADER_API_KEY',
        'AWS_AccessKeyId',
        'AWS_SecretKey',
        'AWS_Bucket',
        'AWS_Region',
        'AWS_Bucket_URL',
        'AWS_Bucket_Folder',
    ];
    for (const variable of optionalVars) {
        if (!process.env[variable]) {
            grunt.warn(`${variable} environment variable not found.  Certain tasks will fail w/o it. Add missing variables to your env file (eg ".env.mydev") (2) run shell command: "export $(grep -v '^#' .env.mydev | xargs)" `);
        }
    }
    grunt.log.writeln(grunt_this.target + ' message=' + grunt_this.data.msg);
};
