var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/* eslint-disable new-cap */
import logManager from "../utils/log-manager";
const logger = logManager.getLogger("image-loader");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const eventStream = require("event-stream");
import { createReadStream } from "fs";
import { once } from "events";
import imageImporter from "./image-importer";
import { gateway } from "../utils/gateway";
let buffer = [];
export function readFileAndLoad(sourceFilePath, imageDirectory, options) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("readFileAndLoad");
        const { batchSize, deleteExisting, imageImportConcurrency } = options;
        const processedSku = [];
        buffer = [];
        const pause = eventStream.pause();
        const pipeline = createReadStream(sourceFilePath)
            .pipe(eventStream.split())
            .pipe(eventStream.parse({ error: true }))
            .pipe(pause)
            .on("data", (record) => __awaiter(this, void 0, void 0, function* () {
            if (buffer.push(record) === batchSize) {
                pause.pause();
                yield imageImporter.importImages(gateway, buffer, imageDirectory, processedSku, {
                    deleteExisting,
                    imageImportConcurrency,
                });
                logger.info(`Processed ${buffer.length} images.`);
                buffer = [];
                pause.resume();
            }
        }))
            .on("error", (error) => {
            logger.error(`Error processing file:`, error);
        });
        if (pipeline) {
            yield once(pipeline, "end");
            if (buffer.length > 0) {
                yield imageImporter.importImages(gateway, buffer, imageDirectory, processedSku, {
                    deleteExisting,
                    imageImportConcurrency,
                });
            }
            logger.info(`Processed ${buffer.length} images.`);
        }
    });
}
