var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import https from "https";
import { inspect } from "util";
import logManager from "./log-manager";
const logger = logManager.getLogger("epcc-sdk-gateway");
import throttledQueue from "throttled-queue";
let httpsAgent;
let throttle;
const configure = (options) => {
    throttle = throttledQueue(Number(options === null || options === void 0 ? void 0 : options.epccClientThrottleLimit) || 6, Number(options === null || options === void 0 ? void 0 : options.epccClientThrottleInterval) || 250);
    httpsAgent = new https.Agent({
        keepAlive: (options === null || options === void 0 ? void 0 : options.epccClientKeepAlive) === "true",
        keepAliveMsecs: Number(options === null || options === void 0 ? void 0 : options.epccClientHttpKeepAliveInterval) || 10000,
    });
};
function debugFetch(url, options) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!throttle) {
            configure();
        }
        logger.debug(`----------- Request to ${url} ---------------\n ${inspect(options, false, 5, true)}`);
        // @ts-ignore Not sure how to properly type this to the `node-fetch` namespace
        const response = yield throttle(() => __awaiter(this, void 0, void 0, function* () { return globalThis.fetch(url, options); }));
        const responseBody = yield response.text();
        if (response.status >= 400 && ![404].includes(response.status)) {
            logger.warn(`----------- Response HTTP Status: ${response.status}/${response.statusText} received for ${url} ------------
       Request body: ${inspect(options, false, 5, true)}`);
        }
        else {
            logger.debug(`----------- Response for ${options.method} ${url} ------------\n\tHeaders:\n\t ${inspect(response.headers, false, 5, true)} \n\tStatus: ${response.status}/${response.statusText} \n\tBody: ${inspect(responseBody, false, 5, true)}`);
        }
        response.text = () => Promise.resolve(responseBody);
        return response;
    });
}
function keepAliveFetch(url, options) {
    return __awaiter(this, void 0, void 0, function* () {
        options.agent = () => httpsAgent;
        return debugFetch(url, options);
    });
}
export default { throttleFetch: keepAliveFetch, configure };
